#!C:\Miniconda3\conda-bld\gdal-split_1534097352573\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==2.2.4','gcps2wld.py'
__requires__ = 'GDAL==2.2.4'
__import__('pkg_resources').run_script('GDAL==2.2.4', 'gcps2wld.py')
